Welcome to django-real-content’s documentation! — django-real-content 0.1.4 documentation

# Welcome to django-real-content’s documentation!

Django real content is a collection of template tags to quickly show real content instead of misleading lorem ipsum. Useful to get a sense of real world content with fun local unicode characters.

You can view the source code for the project on Github.

## Contents:

- Usage
  - random title
  - random paragraphs
  - random image
- Advanced
  - Need more content?
  - Contributing?

# Installation

You can get Django real content by using pip

    pip install django-real-content

In your project’s settings file add `real_content` to your INSTALLED_APPS setting and `DRC_LANGUAGE` setting (if none is set, english will be used).

    INSTALLED_APPS = (
        # ...
        'real_content',
    )

    DRC_LANGUAGE = 'hr'

## Languages currently supported out of the box

- cz, de, en, es, fr, hr, it, nl, ru, si